@@ -290,6 +290,13 @@ class TestBitbakeWatch(TestWatch):
         s3 = next(watch)
         assert s3.state == "finished"
 
+    def test_watch_infrastructure_error(self, bitbake, bitbake_statuses):
+        bitbake_statuses[-1]["state"] = "finished"
+        bitbake_statuses[-1]["result"] = "error"
+        bitbake_statuses[-1]["message"] = "Infrastructure Error"
+
+        self.watch(bitbake)
+
     def test_watch_pass_warnings(self, bitbake, bitbake_statuses):
         bitbake_statuses[-1]["warnings_count"] = 5
 
