@@ -155,6 +155,11 @@ def test_plan_config_job_name(plan_config):
     }
 
 
+def test_plan_config_version(plan_config_unknown_version):
+    with pytest.raises(InvalidConfiguration):
+        PlanConfig("hello", "world", plan_config_unknown_version, "gcc-simple")
+
+
 def test_submit(config, plan_config, mocker):
     cfg = PlanConfig("", "", plan_config)
     plan = Plan(
